import type { Express } from "express";
import type { Contract } from "web3-eth-contract";
import type { TransactionReceipt } from "web3-eth";
import { ConsensusAlgorithmFamily, IPluginLedgerConnector, IWebServiceEndpoint, IPluginWebService, ICactusPlugin, ICactusPluginOptions } from "@hyperledger/cactus-core-api";
import { PluginRegistry } from "@hyperledger/cactus-core";
import { LogLevelDesc } from "@hyperledger/cactus-common";
import { ConsistencyStrategy, DeployContractJsonObjectV1Request, DeployContractV1Request, DeployContractV1Response, DeployRequestBaseV1, InvokeContractJsonObjectV1Request, InvokeContractV1Request, InvokeContractV1Response, InvokeRequestBaseV1, RunTransactionV1Request, RunTransactionV1Response } from "./generated/openapi/typescript-axios";
import { PrometheusExporter } from "./prometheus-exporter/prometheus-exporter";
export declare const E_KEYCHAIN_NOT_FOUND = "cactus.connector.xdai.keychain_not_found";
export interface IPluginLedgerConnectorXdaiOptions extends ICactusPluginOptions {
    rpcApiHttpHost: string;
    pluginRegistry: PluginRegistry;
    prometheusExporter?: PrometheusExporter;
    logLevel?: LogLevelDesc;
}
export declare class PluginLedgerConnectorXdai implements IPluginLedgerConnector<DeployContractV1Request, DeployContractV1Response, RunTransactionV1Request, RunTransactionV1Response>, ICactusPlugin, IPluginWebService {
    readonly options: IPluginLedgerConnectorXdaiOptions;
    private readonly instanceId;
    prometheusExporter: PrometheusExporter;
    private readonly log;
    private readonly web3;
    private readonly pluginRegistry;
    private contracts;
    private endpoints;
    private httpServer;
    static readonly CLASS_NAME = "PluginLedgerConnectorXdai";
    get className(): string;
    constructor(options: IPluginLedgerConnectorXdaiOptions);
    getOpenApiSpec(): unknown;
    hasTransactionFinality(): Promise<boolean>;
    getPrometheusExporter(): PrometheusExporter;
    getPrometheusExporterMetrics(): Promise<string>;
    getInstanceId(): string;
    onPluginInit(): Promise<unknown>;
    shutdown(): Promise<void>;
    registerWebServices(app: Express): Promise<IWebServiceEndpoint[]>;
    getOrCreateWebServices(): Promise<IWebServiceEndpoint[]>;
    getPackageName(): string;
    getConsensusAlgorithmFamily(): Promise<ConsensusAlgorithmFamily>;
    /**
     * Verifies that it is safe to call a specific method of a Web3 Contract.
     *
     * @param contract The Web3 Contract instance to check whether it has a method with a specific name or not.
     * @param name The name of the method that will be checked if it's usable on `contract` or not.
     * @returns Boolean `true` when it IS safe to call the method named `name` on the contract.
     * @throws If the contract instance is falsy or it's methods object is falsy. Also throws if the method name is a blank string.
     */
    isSafeToCallContractMethod(contract: InstanceType<typeof Contract>, name: string): Promise<boolean>;
    runInvoke(req: InvokeRequestBaseV1): Promise<InvokeContractV1Response>;
    invokeContract(req: InvokeContractV1Request): Promise<InvokeContractV1Response>;
    invokeContractJsonObject(req: InvokeContractJsonObjectV1Request): Promise<InvokeContractV1Response>;
    transact(req: RunTransactionV1Request): Promise<RunTransactionV1Response>;
    transactSigned(req: RunTransactionV1Request): Promise<RunTransactionV1Response>;
    transactPrivateKey(req: RunTransactionV1Request): Promise<RunTransactionV1Response>;
    transactCactusKeychainRef(req: RunTransactionV1Request): Promise<RunTransactionV1Response>;
    pollForTxReceipt(txHash: string, consistencyStrategy: ConsistencyStrategy): Promise<TransactionReceipt>;
    private generateBytecode;
    runDeploy(req: DeployRequestBaseV1): Promise<DeployContractV1Response>;
    deployContract(req: DeployContractV1Request): Promise<DeployContractV1Response>;
    deployContractJsonObject(req: DeployContractJsonObjectV1Request): Promise<DeployContractV1Response>;
}
